@@ -5,20 +5,11 @@ test -z "$srcdir" && srcdir=.
 
 PKG_NAME="sigc++"
 
-(test -f "$srcdir/configure.in" \
-  && test -d "$srcdir/sigc++" \
-  && test -d "$srcdir/sigc++/macros") || {
-    echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
-    echo " top-level $PKG_NAME directory"
-    exit 1
-}
-
-
 echo "Adding libtools."
 libtoolize --automake --copy
 
 echo "Building macros."
-aclocal -I scripts $ACLOCAL_FLAGS
+aclocal  -I "$srcdir/scripts" $ACLOCAL_FLAGS
 
 #echo "Building config header."
 #autoheader
